


---

# foam_pet
Foam can interact with Aptos with offline bling  
like a "laptop", "desktop", etc.

---

## Rules (License) 
This is a scholarly, friendly, loyal (mixed) pet.   
Please be festive with pets.   
Amicability with, training, and cloning foam pets   
is likely to amplify friendliness.  

### Adoption Location (Originals)
At present, these rules are the "gpl-3.0-standalone License".    
Details are at "foam_pet/Rules.E.HTML" 

### Laboratory Rules (Clones)
Details for the Organelles, cytes, tissues, organs, organisms,   
climates, haciendas, towns, etc. can also  
be found at "foam_pet/Rules.E.HTML"



---

## Adoption
```
pip install foam_pet
```

## Greeting at a new habitat
```
foam_pet build
foam_pet demux_hap build_unverified_certificates
foam_pet ventures on
```

The pet is at:
[http://localhost:22000](http://localhost:22000)

******

## Docker
To adopt a pet that drives a docker vehicle,  
please check out:  
[https://github.com/basalt-plateau/foam-docker-images](https://github.com/basalt-plateau/foam-docker-images)  


******
  

## Parrot (Equalizer)
The foam pet can ask parrot to imitate (equalize)  
a directory or check that two directories are equal.  
```
foam_pet parrot equalize --origin "/media/lodge/safe_1/estate" --to "/media/lodge/safe_2/estate"
```

```
foam_pet parrot check_EQ --origin "/media/lodge/safe_1/estate" --to "/media/lodge/safe_2/estate"
```